@@ -11,12 +11,12 @@ import json
 import urllib.request as request
 from tqdm import tqdm
 import time
+
 from fuzzup.utils import complist
 
 logging.basicConfig(level=logging.INFO)
 logger = logging.getLogger(__name__)
 
-
 # helper function
 def clean_string(x):
     out = re.sub(r"\([^()]*\)", "", x)
@@ -142,21 +142,21 @@ def get_cities():
     out = {}
     for row in df.itertuples(index=False, name="row"):
         out[row.navn] = {'municipality': row.municipality,
-                         'city_code': row.city_code}                
+                         'eblocal_code': row.city_code}                
     
     return out
 
 def get_municipalities():
     url = 'https://api.dataforsyningen.dk/kommuner'
     data = requests.get(url).json() 
-    whitelist = {x.get('navn'): {'municipality_code': x.get('kode')} for x in data}
+    whitelist = {" ".join([x.get('navn'), "Kommune"]): {'municipality_code': x.get('kode')} for x in data}
     return whitelist
 
 def get_neighborhoods():
     """Get all neighborhoods in DK"""
     url = 'https://api.dataforsyningen.dk/steder?hovedtype=Bebyggelse&undertype=bydel'
     hoods = requests.get(url).json()
-    out = {hood['primærtnavn'] : {'neighborhood_code': hood['id']} for hood in hoods}
+    out = {hood['primærtnavn'] : {'eblocal_code': hood['id']} for hood in hoods}
     return out
     
 # helper function
@@ -328,6 +328,8 @@ def format_helper(x: List[Dict], columns: List[str]=['neighborhood_code', 'city_
                     if col in df:
                         out[col] = df[col]
                 output.append(out)
+    if len(output) == 0:
+        return pd.DataFrame()
     output = pd.concat(output, ignore_index=True)
     return output
 
@@ -352,7 +354,7 @@ def format_output(results: List[Dict],
     Returns:
         pd.DataFrame: Output in desired format.
     """
-    results = [format_helper(results.get(x)) for x in results]
+    results = [format_helper(x=results.get(x), columns=columns) for x in results]
     results = pd.concat(results, ignore_index=True)
     if drop_duplicates:
         results.drop_duplicates(inplace=True, keep="first")
